OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Stiki",
    "Copy Url to clipboard" : "Kopiraj naslov URL v odložišče",
    "Download" : "Prejmi",
    "ShowURL" : "Pokaži naslov URL",
    "Share Addressbook" : "Souporaba imenika",
    "Delete Addressbook" : "Izbriši imenik",
    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
    "Delete" : "Izbriši",
    "can edit" : "lahko ureja",
    "Address book name" : "Ime imenika",
    "Import" : "Uvozi",
    "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
    "No contacts in here" : "Ni dodanega nobenega stika!",
    "Name" : "Ime",
    "Organization" : "Ustanova",
    "Title" : "Naslov",
    "Add field ..." : "Dodaj polje ...",
    "No search result for {query}" : "Ni zadetkov iskanja za {query}",
    "_%n contact_::_%n contacts_" : ["%n stik","%n stika","%n stiki","%n stikov"],
    "Post office box" : "Poštni predal",
    "Postal code" : "Poštna številka",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Country" : "Država",
    "Address" : "Naslov",
    "(new group)" : "(nova skupina)",
    "Last name" : "Priimek",
    "First name" : "Ime",
    "Additional names" : "Druga imena",
    "Prefix" : "Predpona",
    "Suffix" : "Pripona",
    "All contacts" : "Vsi stiki",
    "Not grouped" : "Brez skupine",
    "New contact" : "Nov stik",
    "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
    "Contact could not be created." : "Stika ni mogoče ustvariti.",
    "No contacts in file. Only VCard files are allowed." : "V datoteki ni vpisanih stikov. Dovoljeni so le vpisi datotek VCard.",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podprti sta le različici VCard 4.0 (RFC6350) in VCard 3.0 (RFC2426).",
    "Nickname" : "Vzdevek",
    "Detailed name" : "Podrobno ime",
    "Notes" : "Sporočilca",
    "Website" : "Spletna stran",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Domači naslov",
    "Work" : "Službeni naslov",
    "Other" : "Drugo",
    "Groups" : "Skupine",
    "Birthday" : "Rojstni dan",
    "Anniversary" : "Obletnica",
    "Date of death" : "Datum smrti",
    "Email" : "Elektronski naslov",
    "Instant messaging" : "Hipno sporočanje",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni telefon",
    "Fax" : "Faks",
    "Fax home" : "Domači faks",
    "Fax work" : "Službeni faks",
    "Pager" : "Pozivnik",
    "Voice" : "Glas",
    "Social network" : "Družbeno omrežje",
    "Settings" : "Nastavitve"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
